@@ -1,9 +1,9 @@
-# $Id: XSH.pm,v 1.3 2002/03/14 17:33:47 pajas Exp $
+# $Id: XSH.pm,v 1.5 2002/08/30 17:08:37 pajas Exp $
 
 package XML::XSH;
 
 use strict;
-use vars qw(@EXPORT_OK @ISA $VERSION);
+use vars qw(@EXPORT_OK @ISA $VERSION $xshNS);
 
 use Exporter;
 use XML::XSH::Functions qw(:default);
@@ -13,6 +13,7 @@ BEGIN {
   $VERSION   = '1.1';
   @ISA       = qw(Exporter);
   @EXPORT_OK = @XML::XSH::Functions::EXPORT_OK;
+  $xshNS = 'http://xsh.sourceforge.net/xsh/';
 }
 
 1;
