@@ -1,4 +1,4 @@
-# $Id: GDOMECompat.pm,v 1.8 2003/01/22 15:06:12 pajas Exp $
+# $Id: GDOMECompat.pm,v 1.4 2002/08/30 17:10:37 pajas Exp $
 
 package XML::XSH::GDOMECompat;
 
@@ -29,25 +29,10 @@ sub toStringUTF8 {
   }
 }
 
-sub owner_document {
-  my ($self,$node)=@_;
-  if ($self->is_document($node)) {
-    return $node
-  } else {
-    return $node->getOwnerDocument()
-  }
-}
-
 sub doc_URI {
   return undef;
 }
 
-sub set_encoding {
-  my ($class,$dom,$encoding)=@_;
-  croak "Changing document encoding not supported by GDOME\n";
-  return;
-}
-
 sub doc_encoding {
   my ($class,$dom)=@_;
   return '';			# not implemented ?
@@ -95,13 +80,8 @@ sub parser_options {
   my $mode=GDOME_LOAD_PARSING;
   $mode |= GDOME_LOAD_VALIDATING if $XML::XSH::Functions::VALIDATION;
   $mode |= GDOME_LOAD_RECOVERING if $XML::XSH::Functions::RECOVERING;
-  $mode |= GDOME_LOAD_SUBSTITUTE_ENTITIES if $XML::XSH::Functions::PARSER_EXPANDS_ENTITIES;
-  $mode |= GDOME_LOAD_COMPLETE_ATTRS if $XML::XSH::Functions::PARSER_COMPLETES_ATTRIBUTES;
-}
-
-sub load_catalog {
-  croak "catalogs not supported by GDOME\n";
-  return undef;
+  $mode |= GDOME_LOAD_SUBSTITUTE_ENTITIES if $XML::XSH::Functions::EXPAND_ENTITIES;
+  $mode |= GDOME_LOAD_COMPLETE_ATTRS if $XML::XSH::Functions::COMPLETE_ATTRIBUTES;
 }
 
 sub parse_html_file {
@@ -109,25 +89,10 @@ sub parse_html_file {
   return undef;
 }
 
-sub parse_html_fh {
-  croak "HTML parsing not supported by GDOME\n";
-  return undef;
-}
-
-sub parse_sgml_file {
-  croak "DOCBOOK parsing not supported by GDOME\n";
-  return undef;
-}
-
-sub parse_sgml_fh {
-  croak "DOCBOOK parsing not supported by GDOME\n";
-  return undef;
-}
-
 sub parse_string {
   my ($class,$parser,$str)=@_;
   my $doc =$parser->createDocFromString($str,parser_options());
-  if ( $XML::XSH::Functions::PARSER_EXPANDS_XINCLUDE ) {
+  if ( $XML::XSH::Functions::EXPAND_XINCLUDE ) {
     $doc->process_xinclude();
   }
   return $doc;
@@ -138,7 +103,7 @@ sub parse_fh {
   local $/ = undef;
   my $str = <$fh>;
   my $doc = $parser->createDocFromString($str,parser_options());
-  if ( $XML::XSH::Functions::PARSER_EXPANDS_XINCLUDE ) {
+  if ( $XML::XSH::Functions::EXPAND_XINCLUDE ) {
     $doc->process_xinclude();
   }
   return $doc;
@@ -147,7 +112,7 @@ sub parse_fh {
 sub parse_file {
   my ($class,$parser, $uri) = @_;
   my $doc = $parser->createDocFromURI($uri,parser_options());
-  if ( $XML::XSH::Functions::PARSER_EXPANDS_XINCLUDE ) {
+  if ( $XML::XSH::Functions::EXPAND_XINCLUDE ) {
     $doc->process_xinclude();
   }
   return $doc;
@@ -194,9 +159,9 @@ sub is_pi {
   return $node->nodeType == PROCESSING_INSTRUCTION_NODE;
 }
 
-sub is_entity_reference {
+sub is_entity {
   my ($class,$node)=@_;
-  return $node->nodeType == ENTITY_REFERENCE_NODE;
+  return $node->nodeType == ENTITY_NODE;
 }
 
 sub is_document {
@@ -204,7 +169,7 @@ sub is_document {
   return $node->nodeType == DOCUMENT_NODE;
 }
 
-sub is_document_fragment {
+sub is_document {
   my ($class,$node)=@_;
   return $node->nodeType == DOCUMENT_FRAGMENT_NODE;
 }
@@ -223,11 +188,6 @@ sub get_dtd {
   die "Not implemented for GDOME\n";
 }
 
-sub has_dtd {
-  0;
-}
-
-
 sub clone_node {
   my ($class, $dom, $node)=@_;
   return $dom->importNode($node,1);
